@@ -41,6 +41,9 @@ var __async = (__this, __arguments, generator) => new Promise((resolve, reject)
   step((generator = generator.apply(__this, __arguments)).next());
 });
 
+// src/npm/install.ts
+var import_zlib = require("zlib");
+
 // src/console.ts
 var isAction = !!process.env.GITHUB_ACTION, isDebug = process.env.DEBUG === "1" || process.env.LOG_LEVEL === "debug" || process.env.RUNNER_DEBUG === "1";
 function debug(...message) {
@@ -128,24 +131,8 @@ function isRedirect(status) {
 }
 __name(isRedirect, "isRedirect");
 
-// src/spawn.ts
-var import_child_process = __toESM(require("child_process"));
-function spawn(cmd, args, options = {}) {
-  debug("spawn", [cmd, ...args].join(" "));
-  let { status, stdout, stderr } = import_child_process.default.spawnSync(cmd, args, __spreadValues({
-    stdio: "pipe",
-    encoding: "utf-8"
-  }, options));
-  return {
-    exitCode: status != null ? status : 1,
-    stdout,
-    stderr
-  };
-}
-__name(spawn, "spawn");
-
 // src/fs.ts
-var import_path = __toESM(require("path")), import_fs = __toESM(require("fs")), import_os = __toESM(require("os"));
+var import_fs = __toESM(require("fs")), import_os = __toESM(require("os")), import_path = __toESM(require("path"));
 function join(...paths) {
   return import_path.default.join(...paths.flat(2));
 }
@@ -226,6 +213,17 @@ function chmod(path2, mode) {
   debug("chmod", path2, mode), import_fs.default.chmodSync(path2, mode);
 }
 __name(chmod, "chmod");
+function copy(path2, newPath) {
+  debug("copy", path2, newPath);
+  try {
+    import_fs.default.copyFileSync(path2, newPath);
+    return;
+  } catch (error2) {
+    debug("fs.copyFileSync failed", error2);
+  }
+  write(newPath, read(path2));
+}
+__name(copy, "copy");
 function exists(path2) {
   debug("exists", path2);
   try {
@@ -236,9 +234,32 @@ function exists(path2) {
   return !1;
 }
 __name(exists, "exists");
+function link(path2, newPath) {
+  debug("link", path2, newPath);
+  try {
+    import_fs.default.unlinkSync(newPath), import_fs.default.linkSync(path2, newPath);
+    return;
+  } catch (error2) {
+    copy(path2, newPath), debug("fs.linkSync failed, reverting to copy", error2);
+  }
+}
+__name(link, "link");
 
-// src/npm/install.ts
-var import_zlib = require("zlib");
+// src/spawn.ts
+var import_child_process = __toESM(require("child_process"));
+function spawn(cmd, args, options = {}) {
+  debug("spawn", [cmd, ...args].join(" "));
+  let { status, stdout, stderr } = import_child_process.default.spawnSync(cmd, args, __spreadValues({
+    stdio: "pipe",
+    encoding: "utf-8"
+  }, options));
+  return {
+    exitCode: status != null ? status : 1,
+    stdout,
+    stderr
+  };
+}
+__name(spawn, "spawn");
 
 // src/platform.ts
 var os2 = process.platform, arch = os2 === "darwin" && process.arch === "x64" && isRosetta2() ? "arm64" : process.arch, avx2 = arch === "x64" && (os2 === "linux" && isLinuxAVX2() || os2 === "darwin" && isDarwinAVX2() || os2 === "win32" && isWindowsAVX2()), abi = os2 === "linux" && isLinuxMusl() ? "musl" : void 0, platforms = [
@@ -418,7 +439,7 @@ function installBun(platform, dst) {
     write(join(cwd, "package.json"), "{}");
     let { exitCode } = spawn(
       "npm",
-      ["install", "--loglevel=error", "--prefer-offline", "--no-audit", "--progress=false", `${module2}@1.2.13`],
+      ["install", "--loglevel=error", "--prefer-offline", "--no-audit", "--progress=false", `${module2}@1.2.18`],
       {
         cwd,
         stdio: "pipe",
@@ -439,7 +460,7 @@ function installBun(platform, dst) {
 __name(installBun, "installBun");
 function downloadBun(platform, dst) {
   return __async(this, null, function* () {
-    let tgz = yield (yield fetch(`https://registry.npmjs.org/@oven/${platform.bin}/-/${platform.bin}-1.2.13.tgz`)).arrayBuffer(), buffer;
+    let tgz = yield (yield fetch(`https://registry.npmjs.org/@oven/${platform.bin}/-/${platform.bin}-1.2.18.tgz`)).arrayBuffer(), buffer;
     try {
       buffer = (0, import_zlib.unzipSync)(tgz);
     } catch (cause) {
@@ -468,7 +489,7 @@ __name(downloadBun, "downloadBun");
 function optimizeBun(path2) {
   let installScript = os2 === "win32" ? 'powershell -c "irm bun.sh/install.ps1 | iex"' : "curl -fsSL https://bun.sh/install | bash";
   try {
-    rename(path2, join(__dirname, "bin", "bun.exe"));
+    rename(path2, join(__dirname, "bin", "bun.exe")), link(join(__dirname, "bin", "bun.exe"), join(__dirname, "bin", "bunx.exe"));
     return;
   } catch (error2) {
     debug("optimizeBun failed", error2);
